import {
  select,
  csv, 
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 40, right: 40, bottom: 60, left: 150};
  const innerwidth = width - margin.left -margin.right;
  const innerheight = height - margin.top -margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerwidth]);
  
  //const Axis = axisLeft(yScale);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0,innerheight]); 
  
  const g = svg.append('g')
    .attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxisTickFormat = number => format('.3s')(number)
       .replace('G','B');
  const xAxis = axisBottom(xScale).tickFormat(xAxisTickFormat).tickSize(-innerheight);
  
  g.append('g')
     .call(axisLeft(yScale))
     .selectAll('.domain, .tick line')
     .remove();
  
  const xAxisG = g.append('g')
    .call(xAxis)
    .attr('transform', `translate(0, ${innerheight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class','axis-label')
      .attr('y',45).attr('x',innerwidth/2)
      .attr('fill','black')
      .text('Population');
  
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth());  
  
  g.append('text')
      .attr('class','title')
      .attr('y',-5).attr('x',100)
      .text('Top 10 most popular countries');
  
};



csv('data.csv').then(data => {
	data.forEach( d=>{
    d.population = +d.population * 1000;
  });  
  render(data);
});